"""Python Wrapper for WeatherFlow REST API."""
from pyweatherflowrest.api import WeatherFlowApiClient
from pyweatherflowrest.exceptions import BadRequest, Invalid, NotAuthorized, WrongStationID

__all__ = [
    "Invalid",
    "NotAuthorized",
    "BadRequest",
    "WrongStationID",
    "WeatherFlowApiClient",
]


"""Exception handling for WeatherFlow Rest."""
class WeatherFlowError(Exception):
    """Base class for all other WeatherFlow errors."""


class ClientError(WeatherFlowError):
    """Base Class for all other Unifi Protect client errors."""


class BadRequest(ClientError):
    """Invalid request from API Client."""


class Invalid(ClientError):
    """Invalid return from Authorization Request."""


class NotAuthorized(ClientError):
    """Wrong API Token."""


class WrongStationID(ClientError):
    """Station ID does not exist."""
